@@ -220,7 +220,7 @@ class LoopDataParserRevB(DataParser):
         # AlarmSoilLeaf 8bits, 4 bytes
         for i in range(1, 5):
             data = self.raw_bytes[81 + i]
-            LOGGER.error(data)
+            LOGGER.error(self.raw_bytes)
             self['AlarmSoilLeaf'] = bytes_to_binary(data)
             self['Alarm%.2dLowLeafWet' % i] = int(self['AlarmSoilLeaf'][0])
             self['Alarm%.2dHighLeafWet' % i] = int(self['AlarmSoilLeaf'][0])
